[data-afd-control=lookupResultsList],[data-afd-control=reverseGeocodeResultsList]{border:1px solid #6e6e6e;list-style-type:none;padding:0;overflow-y:scroll;max-height:200px;background-color:#fff;li{padding:4px 8px;cursor:pointer}li:hover{background-color:#f5f5f5}li:first-child{padding-top:8px}li:last-child{padding-bottom:8px}}
