.afd-modal-overlay{position:fixed;top:0;left:0;width:100%;height:100%;background-color:#00000080;display:flex;align-items:center;justify-content:center;z-index:1000}.afd-modal{background-color:#fff;padding:20px;border-radius:5px;box-shadow:0 2px 5px #0000004d;max-width:400px;width:90%}.afd-modal-address-suggestion{white-space:pre-line}.afd-modal-button-container{display:flex;justify-content:space-between;margin-top:20px}.afd-modal-button{padding:10px 20px;border:none;border-radius:5px;cursor:pointer}.afd-modal-yes-button{margin-right:10px}
