.afd-loading{position:relative}.afd-loading>:before,.afd-loading>:after{transition:all 0s linear,opacity .2s ease;position:absolute;z-index:3;content:"";top:3.5em;right:1em;margin-top:-.675rem;width:1.35rem;height:1.35rem;box-sizing:border-box;border-radius:500rem;border-style:solid;border-width:.1em}.afd-loading>:before{border-color:#00000059}.afd-loading>:after{animation:button-spin .6s linear;animation-iteration-count:infinite;border-color:#fff transparent transparent;box-shadow:0 0 0 1px transparent}@keyframes button-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}
